"""
pydantic 工具
- pip install pydantic -i https://pypi.tuna.tsinghua.edu.cn/simple/
- pip install Flask
- pip install flask_socketio
- pip install flask_babel
- pip install flask_login
- pip install flask_mail
- pip install flask_paranoid
- pip install flask_security
- pip install email_validator
- pip install flask_sqlalchemy
- pip install simplejson
- pip install flask_migrate

"""
